/******************************************************************
 * Copyright and Permission Notice                                *
 *                                                                *
 * Permission is granted to copy, use, modify, and merge this     *
 * software into your applications and to permit others to do any *
 * of the foregoing for non-commercial use only. You must include *
 * this permission and copyright notice in all copies and         *
 * modified versions of this software, and include attribution    *
 * to Taligent in all splash screens included in any application  *
 * using this software. You must require others to whom you       *
 * distribute this software to do likewise.                       *
 *                                                                *
 * To obtain an unrestricted commercial license to the software   *
 * source and/or binaries, please contact Taligent at             *
 * widgets@taligent.com                                           *
 *                                                                *
 * THE SOFTWARE IS PROVIDED IN ITS 'AS IS' CONDITION FOR          *
 * NON-COMMERCIAL USE ONLY. TALIGENT DISCLAIMS ANY LIABILITY OF   *
 * ANY KIND FOR DAMAGES WHATSOEVER RESULTING FROM THE USE OF      *
 * THIS SOFTWARE.                                                 *
 *                                                                *
 * (C) Copyright Taligent, Inc. 1996,1997-All Rights Reserved.    *
 * (C) Copyright IBM Corporation 1996,1997                        *
 ******************************************************************/

import java.awt.*;
import java.awt.event.*;
import java.net.URL;
import java.util.Date;

import COM.taligent.widget.*;
import COM.taligent.widget.event.*;
import COM.taligent.util.*;

/**
 * Sample tutorial applet to illustrate basic use of the
 * widget.
 *
 * @author  Andy Clark, Taligent Inc.
 * @version 1.0 (JDK 1.1)
 */
public class SampleMultiColumnListbox
    extends java.applet.Applet
    implements CaptionBarListener, ListboxListener,
               ActionListener, ItemListener
    {
    // GUI Components
    MultiColumnListbox listbox;

    Label     andy      = new Label("Andy");
    Checkbox  rich      = new Checkbox("Rich");
    Button    gutierrez = new Button("Gutierrez");
    TextField eugene    = new TextField("Eugene");
    Button    kollar    = new Button("Kollar");

    // Some sample data
    Object rows[][] = {
        { "2", andy,      "Clark"        },
        { "1", "Carl",    "Danowski"     },
        { "3", rich,      gutierrez      },
        { "2", eugene,    "Shumulinsky"  },
        { "1", "Charlie", "Cleveland"    },
        { "3", "Tad",     kollar         }
        };

    /** Setup applet. */
    public void init() {

        setBackground(Color.lightGray);
        setLayout(new BorderLayout());

        // Create a new listbox
        listbox = new MultiColumnListbox();

        // Resize CaptionBar height
        listbox.setCaptionBarHeight(listbox.getCaptionBarHeight() * 2);

        // Create three columns
        String columns[] = { "#", "First\nName", "Last\nName" };
        listbox.addColumns(columns);

        // Change settings for status column
        ListboxColumn column = listbox.getColumnInfo(0);
        column.setWidth(30);
        column.setResizable(false);

        // Change settings for first name column
        column = listbox.getColumnInfo(1);
        column.setSorter(new SelectionSorter());

        // Change settings for last name column
        column = listbox.getColumnInfo(2);
        column.setWidth(100);
        column.setSorter(new SelectionSorter());

        add("Center", listbox);

        Choice choice = new Choice();
        choice.addItem("false");
        choice.addItem("true");

        // Add the data to the listbox
        listbox.addRows(rows);

        // Load the status icons
        URL baseURL = getCodeBase();
        Image images[] = {
            getImage(baseURL, "one.gif"),
            getImage(baseURL, "two.gif"),
            getImage(baseURL, "three.gif")
            };

        StatusIcon icons[] = new StatusIcon[3];
        MediaTracker tracker = new MediaTracker(this);

        for (int i = 0; i < images.length; i++) {
            tracker.addImage(images[i], i);
            icons[i] = new StatusIcon(images[i], i);
            }
        try {
            tracker.waitForAll();
            }
        catch (Exception e) {
            System.err.println("warning: not all images loaded.");
            }

        // Status icons for names
        StatusIcon statusicons[] = { icons[1], icons[0], icons[2],
                                     icons[1], icons[0], icons[2] };

        // Replace the status numbers with icons
        listbox.replaceColumn(statusicons, 0);

        // Allow status column to be sorted
        listbox.getColumnInfo(0).setSorter(new SelectionSorter());
        listbox.getColumnInfo(0).getSorter().setComparator(icons[0]);

        // Resort the listbox
        listbox.sort();

        // add listeners
        listbox.addCaptionBarListener(this);
        listbox.addListboxListener(this);

        rich.addItemListener(this);
        gutierrez.addActionListener(this);
        eugene.addActionListener(this);
        kollar.addActionListener(this);

        setSize(180, 140);
        setVisible(true);
        }

    /** Column was selected. */
    public void captionSelected(CaptionBarEvent evt) {

        //System.out.println(evt.toString());
        }

    /** Column was resized. */
    public void captionResized(CaptionBarEvent evt) {

        //System.out.println(evt.toString());
        }

    /** Row was selected. */
    public void rowSelected(ListboxEvent evt) {

        //System.out.println(evt.toString());
        }

    /** Row was deselected. */
    public void rowDeselected(ListboxEvent evt) {

        //System.out.println(evt.toString());
        }

    /** Button was pressed. */
    public void actionPerformed(ActionEvent evt) {

        //System.out.println(evt.toString());
        }

    /** Item element changed state. */
    public void itemStateChanged(ItemEvent evt) {

        //System.out.println(evt.toString());
        }

    }
