/******************************************************************
 * Copyright and Permission Notice                                *
 *                                                                *
 * Permission is granted to copy, use, modify, and merge this     *
 * software into your applications and to permit others to do any *
 * of the foregoing for non-commercial use only. You must include *
 * this permission and copyright notice in all copies and         *
 * modified versions of this software, and include attribution    *
 * to Taligent in all splash screens included in any application  *
 * using this software. You must require others to whom you       *
 * distribute this software to do likewise.                       *
 *                                                                *
 * To obtain an unrestricted commercial license to the software   *
 * source and/or binaries, please contact Taligent at             *
 * widgets@taligent.com                                           *
 *                                                                *
 * THE SOFTWARE IS PROVIDED IN ITS 'AS IS' CONDITION FOR          *
 * NON-COMMERCIAL USE ONLY. TALIGENT DISCLAIMS ANY LIABILITY OF   *
 * ANY KIND FOR DAMAGES WHATSOEVER RESULTING FROM THE USE OF      *
 * THIS SOFTWARE.                                                 *
 *                                                                *
 * (C) Copyright Taligent, Inc. 1996,1997-All Rights Reserved.    *
 * (C) Copyright IBM Corporation 1996,1997                        *
 ******************************************************************/

import java.awt.*;
import java.awt.event.*;

import COM.taligent.widget.*;

/**
 * Sample progress bar used in tutorial.
 *
 * @author  Andy Clark, Taligent Inc.
 */
public class SampleProgressBar
    extends java.applet.Applet
    implements Runnable,
               MouseListener
    {
    // Data
    ProgressBar progress = new ProgressBar();

    Thread thread;

    // Setup the applet
    public void init() {

        setBackground(Color.lightGray);
        setLayout(new BorderLayout());

        // add components
        BorderPanel border = new BorderPanel(BorderPanelStyle.LOWERED);
        border.setLayout(new BorderLayout());
        border.setGap(0);
        border.add("Center", progress);

        add("Center", border);

        // add listeners
        progress.addMouseListener(this);

        setSize(150, 30);
        setVisible(true);
        }


    // Start the applet
    public void start() {

        thread = new Thread(this);
        thread.start();
        }

    // Stop the applet
    public void stop() {

        if (thread != null) {
            thread.stop();
            thread = null;
            }
        }

    // Make it move!
    public void run() {

        progress.reset();
        while (progress.getValue() < progress.getMaximum()) {
            try {
                // update progress bar
                progress.add((int)(Math.random() * 20));

                // pause a bit to catch our breath
                thread.sleep(333);
                }
            catch (InterruptedException e) {
                // I've been interrupted!
                break;
                }
            }
        }

    // Border applet
    public Insets insets() {

        return new Insets(2, 2, 2, 2);
        }

    // Data
    int    mode;

    // Mouse event handler
    public void mousePressed(MouseEvent evt) {}
    public void mouseReleased(MouseEvent evt) {}
    public void mouseEntered(MouseEvent evt) {}
    public void mouseExited(MouseEvent evt) {}

    public void mouseClicked(MouseEvent evt) {
        Object source = evt.getSource();

        if (source == progress) {
            if (thread != null)
                thread.stop();

            mode = (mode + 1) % 7;
            switch (mode) {
                case 0:
                    progress.setStyle(ProgressBarStyle.SOLID);
                    progress.setDirection(ProgressBarDirection.RIGHT);
                    break;
                case 1:
                    progress.setPercent(true);
                    break;
                case 2:
                    progress.setPercent(false);
                    progress.setDirection(ProgressBarDirection.LEFT);
                    break;
                case 3:
                    progress.setStyle(ProgressBarStyle.BLOCK);
                    progress.setDirection(ProgressBarDirection.RIGHT);
                    break;
                case 4:
                    progress.setDirection(ProgressBarDirection.LEFT);
                    break;
                case 5:
                    progress.setStyle(ProgressBarStyle.STRIPED);
                    progress.setDirection(ProgressBarDirection.RIGHT);
                    break;
                case 6:
                    progress.setDirection(ProgressBarDirection.LEFT);
                    break;
                }

            if (progress.getStyle().isStriped()) {
                if (thread != null) {
                    thread.stop();
                    thread = null;
                    }
                progress.start();
                }
            else {
                progress.stop();
                thread = new Thread(this);
                thread.start();
                }
            }
        }
    }
